pub struct LayoutChild<'a> { /* private fields */ }Expand description
A direct child layout node available during a measure pass.
Implementations
Sourceimpl<'a> LayoutChild<'a>
impl<'a> LayoutChild<'a>
Sourcepub fn measure(
&self,
constraint: &Constraint,
) -> Result<MeasuredChild, MeasurementError>
pub fn measure( &self, constraint: &Constraint, ) -> Result<MeasuredChild, MeasurementError>
Measures this child under the given constraint.
Sourcepub fn measure_untracked(
&self,
constraint: &Constraint,
) -> Result<MeasuredChild, MeasurementError>
pub fn measure_untracked( &self, constraint: &Constraint, ) -> Result<MeasuredChild, MeasurementError>
Measures this child without recording it for layout cache keys.