pub struct LayoutInput<'a> { /* private fields */ }Expand description
Input for a pure layout policy.
Implementations
Sourceimpl<'a> LayoutInput<'a>
impl<'a> LayoutInput<'a>
Sourcepub const fn parent_constraint(&self) -> ParentConstraint<'a>
pub const fn parent_constraint(&self) -> ParentConstraint<'a>
Returns the inherited constraint.
Sourcepub fn children_ids(&self) -> &'a [NodeId]
pub fn children_ids(&self) -> &'a [NodeId]
Returns the children node ids of the current node.
Sourcepub fn measure_children(
&self,
nodes_to_measure: Vec<(NodeId, Constraint)>,
) -> Result<HashMap<NodeId, ComputedData>, MeasurementError>
pub fn measure_children( &self, nodes_to_measure: Vec<(NodeId, Constraint)>, ) -> Result<HashMap<NodeId, ComputedData>, MeasurementError>
Measures all specified child nodes under the given constraint.
Sourcepub fn measure_children_untracked(
&self,
nodes_to_measure: Vec<(NodeId, Constraint)>,
) -> Result<HashMap<NodeId, ComputedData>, MeasurementError>
pub fn measure_children_untracked( &self, nodes_to_measure: Vec<(NodeId, Constraint)>, ) -> Result<HashMap<NodeId, ComputedData>, MeasurementError>
Measures child nodes without recording them for layout cache keys.
Sourcepub fn measure_child(
&self,
child_id: NodeId,
constraint: &Constraint,
) -> Result<ComputedData, MeasurementError>
pub fn measure_child( &self, child_id: NodeId, constraint: &Constraint, ) -> Result<ComputedData, MeasurementError>
Measures a single child node under the given constraint.
Sourcepub fn measure_child_untracked(
&self,
child_id: NodeId,
constraint: &Constraint,
) -> Result<ComputedData, MeasurementError>
pub fn measure_child_untracked( &self, child_id: NodeId, constraint: &Constraint, ) -> Result<ComputedData, MeasurementError>
Measures a child node without recording it for layout cache keys.
Sourcepub fn measure_child_in_parent_constraint(
&self,
child_id: NodeId,
) -> Result<ComputedData, MeasurementError>
pub fn measure_child_in_parent_constraint( &self, child_id: NodeId, ) -> Result<ComputedData, MeasurementError>
Measures a single child node using this node’s inherited constraint.