pub struct PlacementScope<'a> { /* private fields */ }Expand description
Shared placement helpers available during a cached placement pass.
Implementations
Sourceimpl<'a> PlacementScope<'a>
impl<'a> PlacementScope<'a>
Sourcepub const fn parent_constraint(&self) -> ParentConstraint<'a>
pub const fn parent_constraint(&self) -> ParentConstraint<'a>
Returns the inherited constraint.
Sourcepub fn children(&self) -> Vec<PlacementChild<'_>>
pub fn children(&self) -> Vec<PlacementChild<'_>>
Returns the direct child layout nodes of the current node.
Sourcepub const fn size(&self) -> ComputedData
pub const fn size(&self) -> ComputedData
Returns the cached size of the current node.