pub trait RenderPolicy:
Send
+ Sync
+ Clone
+ PartialEq
+ 'static {
// Provided method
fn record(&self, _input: &RenderInput<'_>) { ... }
}Expand description
Render policy for recording draw and compute commands for the current node.
Provided Methods
Sourcefn record(&self, _input: &RenderInput<'_>)
fn record(&self, _input: &RenderInput<'_>)
Records draw and compute commands for the current node.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.